//
//	aegis - project change supervisor
//	Copyright (C) 2004, 2005 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: implementation of the symtab_clear class
//

#include <common/error.h>
#include <common/symtab.h>


void
symtab_ty::clear()
{
    for (str_hash_ty j = 0; j < hash_modulus; ++j)
    {
	row_t **rpp = &hash_table[j];
	while (*rpp)
	{
	    row_t *rp = *rpp;
	    assert(rp->data);
	    assert(rp->key);
	    *rpp = rp->overflow;
	    if (reap)
		reap(rp->data);
	    str_free(rp->key);
	    delete rp;
	}
    }
    hash_load = 0;
}
